@@ -18,10 +18,10 @@
 
 from __base__ import *
 
-class Player(PlayerBase):
+class Player(DBusPlayer):
 	
 	def __init__(self):
-		PlayerBase.__init__(self, "Banshee", "1.5", "org.bansheeproject.Banshee")
+		DBusPlayer.__init__(self, "Banshee", "1.5", "org.bansheeproject.Banshee")
 	
 	@silent
 	def is_playing(self):
