@@ -18,10 +18,10 @@
 
 from __base__ import *
 
-class Player(PlayerBase):
+class Player(DBusPlayer):
 	
 	def __init__(self):
-		PlayerBase.__init__(self, "Exaile", "0.2", "org.exaile.DBusInterface")
+		DBusPlayer.__init__(self, "Exaile", "0.2", "org.exaile.DBusInterface")
 	
 	@silent
 	def get_track(self):
